@@ -27,12 +27,12 @@ class Gene {
     /* Initialisation of mutation matrix (only called by Gene constructor) */
     Vector2D<double> init_mutkernel(const double& mutation_prob);
     /* Initialisation of infectivity and aggressiveness matrices (only called by Gene constructor) */
-    Vector2D<double> init_aggressiveness_matrix(const double& efficiency, const double& fitness_cost,
+    Vector2D<double> init_aggressiveness_matrix(const double& efficiency, const double& adaptation_cost,
                                                 const double& tradeoff_strength);
 
 public:
-    const double time_to_activ_mean;               /* Expected delay to resistance activation (for APRs) */
-    const double time_to_activ_var;               /* Variance of the delay to resistance activation (for APRs) */
+    const double age_of_activ_mean;               /* Expected delay to resistance activation (for APRs) */
+    const double age_of_activ_var;               /* Variance of the delay to resistance activation (for APRs) */
     const int Nlevels_aggressiveness;             /* Number of adaptation levels related to a given aggressiveness component */
     const std::string target_trait;               /* Aggressiveness component targeted by resistance (IR, LAT, IP, PR) */
     const Vector2D<double> mutkernel;             /* Mutation matrix (for pathogen evolution) */
@@ -40,9 +40,9 @@ public:
     const double recombination_sd;                /* Standard deviation of the normal distribution used for recombination of quantitative traits during sexual reproduction (infinitesimal model) */    
 
     Gene();
-    Gene(const double& time_to_activ_mean, const double& time_to_activ_var, const int& Nlevels_aggressiveness,
+    Gene(const double& age_of_activ_mean, const double& age_of_activ_var, const int& Nlevels_aggressiveness,
          const std::string& target_trait, const double& mutation_prob, const double& efficiency,
-         const double& fitness_cost, const double& tradeoff_strength, const double& recombination_sd);
+         const double& adaptation_cost, const double& tradeoff_strength, const double& recombination_sd);
     std::string to_string() const;
 };
 
