@@ -27,22 +27,25 @@ Treatment::Treatment()
     treatment_efficiency(0),
     treatment_timesteps({}),
     treatment_cultivars({}),
-    treatment_cost(0){}
+    treatment_cost(0),
+    treatment_application_threshold({}){}
 
 // Constructor
 Treatment::Treatment(const double& treatment_degradation_rate, const double& treatment_efficiency, const std::vector<int>& treatment_timesteps,
-          const std::vector<int>& treatment_cultivars, const double& treatment_cost)
+          const std::vector<int>& treatment_cultivars, const double& treatment_cost, const std::vector<double>& treatment_application_threshold)
   : treatment_degradation_rate(treatment_degradation_rate),
     treatment_efficiency(treatment_efficiency),
     treatment_timesteps(treatment_timesteps),
     treatment_cultivars(treatment_cultivars),
-    treatment_cost(treatment_cost){}
+    treatment_cost(treatment_cost),
+    treatment_application_threshold(treatment_application_threshold){}
 
 // Transform treatment attributs to string
 std::string Treatment::to_string() const {
-  std::ostringstream oss, oss2;
+  std::ostringstream oss, oss2, oss3;
   std::copy(this->treatment_timesteps.begin(), this->treatment_timesteps.end(), std::ostream_iterator<int>(oss, ", "));
   std::copy(this->treatment_cultivars.begin(), this->treatment_cultivars.end(), std::ostream_iterator<int>(oss2, ", "));
+  std::copy(this->treatment_application_threshold.begin(), this->treatment_application_threshold.end(), std::ostream_iterator<double>(oss3, ", "));
    
   std::string str("");
   str += "  treatment degradation rate:        " + std::to_string(this->treatment_degradation_rate) + "\n";
@@ -50,5 +53,6 @@ std::string Treatment::to_string() const {
   str += "  treatment timesteps:         " + oss.str() + "\n";
   str += "  treatment cultivars:         " + oss2.str() + "\n";
   str += "  treatment cost:    " + std::to_string(this->treatment_cost) + "\n";
+  str += "  treatment application threshold:    " + oss3.str() + "\n";
   return str;
 }
